@@ -279,7 +279,7 @@ class SNDCMP(Dataset):
             {
                 'name': 'ID',
                 'propertyUrl': 'http://cldf.clld.org/v1.0/terms.rdf#id',
-                'valueUrl': 'https://cdstar.shh.mpg.de/bitstreams/{objid}/{fname}',
+                'valueUrl': 'https://cdstar.eva.mpg.de/bitstreams/{objid}/{fname}',
             },
             'objid',
             'fname',
